KeyGcOptions

Struct KeyGcOptions 

pub struct KeyGcOptions {
    pub max_versions_examined: usize,
    pub collapse_final_tombstones: bool,
}
Options for a read-only, single-key garbage-collection plan.

Fields

max_versions_examined: usize

Maximum number of obsolete, pre-keeper version timestamps to examine.

The planner also performs a fixed number of bounded point lookups to locate the safe-point keeper and determine whether it is the latest committed version. Those point lookups do not consume this history-page budget.

collapse_final_tombstones: bool

Explicit opt-in retention policy for final tombstones.

Callers using this opt-in feature MUST ensure that the safe point is derived from a monotonic log index and that no future read or write will occur below this safe point, as collapsing final tombstones changes read_with_version and guard history semantics below the safe point.